@@ -22,7 +22,6 @@
 #include <KItinerary/Reservation>
 #include <KItinerary/TrainTrip>
 
-#include <KPublicTransport/Journey>
 
 #include <QJSEngine>
 #include <QJSValue>
@@ -403,7 +402,7 @@ static bool isLayover(const QVariant &res1, const QVariant &res2)
 
 KPublicTransport::JourneyRequest TimelineDelegateController::journeyRequest() const
 {
-    if (!m_resMgr || m_batchId.isEmpty()) {
+    if (!m_resMgr || m_batchId.isEmpty() || !m_liveDataMgr) {
         return {};
     }
 
@@ -420,6 +419,7 @@ KPublicTransport::JourneyRequest TimelineDelegateController::journeyRequest() co
     req.setDownloadAssets(true);
     req.setIncludeIntermediateStops(true);
     req.setIncludePaths(true);
+    PublicTransport::selectBackends(req, m_liveDataMgr->publicTransportManager(), res);
 
     // find full journey by looking at subsequent elements
     auto prevRes = res;
@@ -575,6 +575,8 @@ QJSValue TimelineDelegateController::arrivalMapArguments() const
         arrPlatform = res.value<TrainReservation>().reservationFor().value<TrainTrip>().arrivalPlatform();
     }
     args.setProperty(QStringLiteral("arrivalPlatformName"), arrPlatform);
+    args.setProperty(QStringLiteral("arrivalPlatformMode"), KOSMIndoorMap::Platform::Rail);
+    args.setProperty(QStringLiteral("arrivalPlatformIfopt"), arr.stopPoint().identifier(QStringLiteral("ifopt")));
     // there is no arrival gate property (yet)
 
     // arrival time
@@ -592,6 +594,8 @@ QJSValue TimelineDelegateController::arrivalMapArguments() const
     if (transfer.state() == Transfer::Selected) {
         const auto dep = PublicTransport::firstTransportSection(transfer.journey());
         args.setProperty(QStringLiteral("departurePlatformName"), dep.hasExpectedDeparturePlatform() ? dep.expectedDeparturePlatform() : dep.scheduledDeparturePlatform());
+        args.setProperty(QStringLiteral("departurePlatformMode"), PublicTransport::lineModeToPlatformMode(dep.route().line().mode()));
+        args.setProperty(QStringLiteral("departurePlatformIfopt"), dep.from().identifier(QStringLiteral("ifopt")));
         args.setProperty(QStringLiteral("endTime"), engine->toScriptValue(dep.hasExpectedDepartureTime() ? dep.expectedDepartureTime() : dep.scheduledDepartureTime()));
         return args;
     }
@@ -608,6 +612,8 @@ QJSValue TimelineDelegateController::arrivalMapArguments() const
         depPlatform = nextRes.value<TrainReservation>().reservationFor().value<TrainTrip>().departurePlatform();
     }
     args.setProperty(QStringLiteral("departurePlatformName"), depPlatform);
+    args.setProperty(QStringLiteral("departurePlatformMode"), PublicTransport::lineModeToPlatformMode(dep.route().line().mode()));
+    args.setProperty(QStringLiteral("departurePlatformIfopt"), dep.stopPoint().identifier(QStringLiteral("ifopt")));
     if (JsonLd::isA<FlightReservation>(nextRes)) {
         args.setProperty(QStringLiteral("departureGateName"), nextRes.value<FlightReservation>().reservationFor().value<Flight>().departureGate());
     }
@@ -645,6 +651,8 @@ QJSValue TimelineDelegateController::departureMapArguments() const
         depPlatform = res.value<TrainReservation>().reservationFor().value<TrainTrip>().departurePlatform();
     }
     args.setProperty(QStringLiteral("departurePlatformName"), depPlatform);
+    args.setProperty(QStringLiteral("departurePlatformMode"), KOSMIndoorMap::Platform::Rail);
+    args.setProperty(QStringLiteral("departurePlatformIfopt"), dep.stopPoint().identifier(QStringLiteral("ifopt")));
     if (JsonLd::isA<FlightReservation>(res)) {
         args.setProperty(QStringLiteral("departureGateName"), res.value<FlightReservation>().reservationFor().value<Flight>().departureGate());
     }
@@ -664,6 +672,8 @@ QJSValue TimelineDelegateController::departureMapArguments() const
     if (transfer.state() == Transfer::Selected) {
         const auto arr = PublicTransport::lastTransportSection(transfer.journey());
         args.setProperty(QStringLiteral("arrivalPlatformName"), arr.hasExpectedArrivalPlatform() ? arr.expectedArrivalPlatform() : arr.scheduledArrivalPlatform());
+        args.setProperty(QStringLiteral("arrivalPlatformMode"), PublicTransport::lineModeToPlatformMode(arr.route().line().mode()));
+        args.setProperty(QStringLiteral("arrivalPlatformIfopt"), arr.to().identifier(QStringLiteral("ifopt")));
         args.setProperty(QStringLiteral("beginTime"), engine->toScriptValue(arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime()));
         return args;
     }
@@ -680,6 +690,8 @@ QJSValue TimelineDelegateController::departureMapArguments() const
         arrPlatform = prevRes.value<TrainReservation>().reservationFor().value<TrainTrip>().arrivalPlatform();
     }
     args.setProperty(QStringLiteral("arrivalPlatformName"), arrPlatform);
+    args.setProperty(QStringLiteral("arrivalPlatformMode"), PublicTransport::lineModeToPlatformMode(dep.route().line().mode()));
+    args.setProperty(QStringLiteral("arrivalPlatformIfopt"), dep.stopPoint().identifier(QStringLiteral("ifopt")));
     // there is no arrival gate property (yet)
 
     auto arrTime = arr.hasExpectedArrivalTime() ? arr.expectedArrivalTime() : arr.scheduledArrivalTime();
